==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicScrollBarUI__24ArrowButtonListener.h <==
// public class javax.swing.plaf.basic.BasicScrollBarUI$ArrowButtonListener

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f0a48d5b45119dc3 javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener_H_
#define _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vmethods	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtable	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method$_init$5dc65915419aac46(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method_info$mouseReleased$47ad6ad312932c8e;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vmethods {
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vmethods	javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$refs {
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_refs	javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_nonrefs	javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object {
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicScrollBarUI__24ArrowButtonListener.h <==
// public class javax.swing.plaf.basic.BasicScrollBarUI$ArrowButtonListener

// class file dependencies
// @dep_class 1753c91cef0fc2dd java_awt_event_MouseAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f0a48d5b45119dc3 javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener

// header file dependencies
// @dep_header java_awt_event_MouseAdapter

#include "java/awt/event/MouseAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener_H_
#define _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$refs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$nonrefs	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vmethods	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtable	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method$_init$5dc65915419aac46(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$method_info$mouseReleased$47ad6ad312932c8e;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vmethods {
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseAdapter$vmethods	java_awt_event_MouseAdapter;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vmethods	javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicScrollBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$refs {
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_refs	javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener;
    _jc_java_awt_event_MouseAdapter$sub_refs	java_awt_event_MouseAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseAdapter$sub_nonrefs	java_awt_event_MouseAdapter;
    _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$sub_nonrefs	javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$object {
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$vtype _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicScrollBarUI__24ArrowButtonListener_H_ */
